@@ -136,7 +136,7 @@ dev.off()
 }
 if (plotype==2){
 {
-jpeg(file=fileName)
+jpeg(filename=fileName)
 internalSTD()
 }
 dev.off()
